MapEntity
=========

MapEntity is a CRUD interface for geospatial entities built with Django,
that powers
- `Geotrek <https://github.com/GeotrekCE/Geotrek-admin.fr>`_.
- `Georiviere <https://github.com/Georiviere/Georiviere-admin>`_.


Works with Python 3.6+ and Django 2.2+

.. image:: https://img.shields.io/pypi/v/mapentity.svg
    :target: https://pypi.python.org/pypi/mapentity

.. image:: https://github.com/makinacorpus/django-mapentity/actions/workflows/python-ci.yml/badge.svg

.. image:: https://codecov.io/gh/makinacorpus/django-mapentity/branch/master/graph/badge.svg?token=lFNYhcVjuz
    :target: https://codecov.io/gh/makinacorpus/django-mapentity


`See the full documentation <http://django-mapentity.readthedocs.org/>`_.


=======
AUTHORS
=======

|makinacom|_

.. |makinacom| image:: https://github.com/makinacorpus.png
.. _makinacom:  https://www.makina-corpus.com


=======
LICENSE
=======

    * BSD New
